An S3 class of type quant_param from the dials package.
Arguments
range
A two-element vector holding the defaults for the smallest and
largest possible values, respectively. If a transformation is specified,
these values should be in the transformed units.
trans
A trans object from the scales package, such as
scales::log10_trans() or scales::reciprocal_trans().If not provided, the
default is used which matches the units used in range. If no transformation,
NULL.
Details
Softening parameter. Usually has the least affect on performance.