Learn R Programming

tidydann (version 1.0.1)

tunable.nearest_neighbor_adaptive: Declare tunable parameters

Description

Returns information on potential hyper-parameters that can be optimized.

Usage

# S3 method for nearest_neighbor_adaptive
tunable(x, ...)

Value

A tibble with a column for the parameter name, information on the default method for generating a corresponding parameter object, the source of the parameter (e.g. "recipe", etc.), and the component within the source.

Arguments

x

A model specification of type nearest_neighbor_adaptive specification.

...

Other arguments passed to methods.